@@ -17,7 +17,7 @@ dst=
 #part2
 echo "Installing Web script..."
 wwwdirselect=/var/www
-echo $n "Enter apache web root directory[$wwwdirselect]: $c"
+echo -n "Enter apache web root directory[$wwwdirselect]: "
 read wwwdiruser
 if [ -n "$wwwdiruser" ]; then
 	wwwdirselect=$wwwdiruser
